# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteFeed(BaseModel):
    delete_feed: Optional["DeleteFeedDeleteFeed"] = Field(alias="deleteFeed")


class DeleteFeedDeleteFeed(BaseModel):
    id: str
    state: EntityState


DeleteFeed.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalProcedure(BaseModel):
    delete_medical_procedure: Optional[
        "DeleteMedicalProcedureDeleteMedicalProcedure"
    ] = Field(alias="deleteMedicalProcedure")


class DeleteMedicalProcedureDeleteMedicalProcedure(BaseModel):
    id: str
    state: EntityState


DeleteMedicalProcedure.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteObservation(BaseModel):
    delete_observation: Optional["DeleteObservationDeleteObservation"] = Field(
        alias="deleteObservation"
    )


class DeleteObservationDeleteObservation(BaseModel):
    id: str
    state: EntityState


DeleteObservation.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryPersons(BaseModel):
    persons: Optional["QueryPersonsPersons"]


class QueryPersonsPersons(BaseModel):
    results: Optional[List[Optional["QueryPersonsPersonsResults"]]]


class QueryPersonsPersonsResults(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    relevance: Optional[float]
    address: Optional["QueryPersonsPersonsResultsAddress"]
    email: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    family_name: Optional[str] = Field(alias="familyName")
    phone_number: Optional[str] = Field(alias="phoneNumber")
    birth_date: Optional[Any] = Field(alias="birthDate")
    title: Optional[str]
    occupation: Optional[str]
    education: Optional[str]


class QueryPersonsPersonsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


QueryPersons.model_rebuild()
QueryPersonsPersons.model_rebuild()
QueryPersonsPersonsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteEvent(BaseModel):
    delete_event: Optional["DeleteEventDeleteEvent"] = Field(alias="deleteEvent")


class DeleteEventDeleteEvent(BaseModel):
    id: str
    state: EntityState


DeleteEvent.model_rebuild()



import os
import jwt
import datetime
import httpx
from graphlit_api.client import Client

class Graphlit:
    def __init__(self, organization_id=None, environment_id=None, jwt_secret=None, owner_id=None, api_uri=None):
        self.organization_id = organization_id if organization_id is not None else os.getenv("GRAPHLIT_ORGANIZATION_ID")
        self.environment_id = environment_id if environment_id is not None else os.getenv("GRAPHLIT_ENVIRONMENT_ID")
        self.owner_id = owner_id if owner_id is not None else os.getenv("GRAPHLIT_OWNER_ID")
        self.secret_key = jwt_secret if jwt_secret is not None else os.getenv("GRAPHLIT_JWT_SECRET")
        self.api_uri = api_uri if api_uri is not None else "https://data-scus.graphlit.io/api/v1/graphql/"
        
        self.refresh_client()
        
    def refresh_client(self):
        self.client = None
        self._generate_token()
        
        headers = {"Authorization": f"Bearer {self.token}"}

        timeout = httpx.Timeout(connect=10.0, read=600.0, write=10.0, pool=60.0)
        
        self.client = Client(url=self.api_uri, headers=headers)
        self.client.http_client.timeout = timeout

    def _generate_token(self):
        expiration = datetime.datetime.now(datetime.timezone.utc) + datetime.timedelta(days=1)
        
        payload = {
            "https://graphlit.io/jwt/claims": {
                "x-graphlit-organization-id": self.organization_id,
                "x-graphlit-environment-id": self.environment_id,
                "x-graphlit-role": "Owner",
            },
            "exp": expiration,
            "iss": "graphlit",
            "aud": "https://portal.graphlit.io",
        }

        if self.owner_id is not None:
            payload["https://graphlit.io/jwt/claims"]["x-graphlit-owner-id"] = self.owner_id
        
        self.token = jwt.encode(payload, self.secret_key, algorithm="HS256")



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalGuideline(BaseModel):
    create_medical_guideline: Optional[
        "CreateMedicalGuidelineCreateMedicalGuideline"
    ] = Field(alias="createMedicalGuideline")


class CreateMedicalGuidelineCreateMedicalGuideline(BaseModel):
    id: str
    name: str


CreateMedicalGuideline.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class LookupCredits(BaseModel):
    lookup_credits: Optional["LookupCreditsLookupCredits"] = Field(
        alias="lookupCredits"
    )


class LookupCreditsLookupCredits(BaseModel):
    correlation_id: Optional[str] = Field(alias="correlationId")
    owner_id: Optional[str] = Field(alias="ownerId")
    credits: Optional[Any]
    storage_ratio: Optional[Any] = Field(alias="storageRatio")
    compute_ratio: Optional[Any] = Field(alias="computeRatio")
    embedding_ratio: Optional[Any] = Field(alias="embeddingRatio")
    completion_ratio: Optional[Any] = Field(alias="completionRatio")
    ingestion_ratio: Optional[Any] = Field(alias="ingestionRatio")
    indexing_ratio: Optional[Any] = Field(alias="indexingRatio")
    preparation_ratio: Optional[Any] = Field(alias="preparationRatio")
    extraction_ratio: Optional[Any] = Field(alias="extractionRatio")
    classification_ratio: Optional[Any] = Field(alias="classificationRatio")
    enrichment_ratio: Optional[Any] = Field(alias="enrichmentRatio")
    publishing_ratio: Optional[Any] = Field(alias="publishingRatio")
    search_ratio: Optional[Any] = Field(alias="searchRatio")
    conversation_ratio: Optional[Any] = Field(alias="conversationRatio")


LookupCredits.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryOrganizations(BaseModel):
    organizations: Optional["QueryOrganizationsOrganizations"]


class QueryOrganizationsOrganizations(BaseModel):
    results: Optional[List[Optional["QueryOrganizationsOrganizationsResults"]]]


class QueryOrganizationsOrganizationsResults(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    relevance: Optional[float]
    address: Optional["QueryOrganizationsOrganizationsResultsAddress"]
    founding_date: Optional[Any] = Field(alias="foundingDate")
    industries: Optional[List[Optional[str]]]
    revenue: Optional[Any]
    revenue_currency: Optional[str] = Field(alias="revenueCurrency")
    investment: Optional[Any]
    investment_currency: Optional[str] = Field(alias="investmentCurrency")


class QueryOrganizationsOrganizationsResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


QueryOrganizations.model_rebuild()
QueryOrganizationsOrganizations.model_rebuild()
QueryOrganizationsOrganizationsResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalIndication(BaseModel):
    create_medical_indication: Optional[
        "CreateMedicalIndicationCreateMedicalIndication"
    ] = Field(alias="createMedicalIndication")


class CreateMedicalIndicationCreateMedicalIndication(BaseModel):
    id: str
    name: str


CreateMedicalIndication.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMedicalStudies(BaseModel):
    medical_studies: Optional["QueryMedicalStudiesMedicalStudies"] = Field(
        alias="medicalStudies"
    )


class QueryMedicalStudiesMedicalStudies(BaseModel):
    results: Optional[List[Optional["QueryMedicalStudiesMedicalStudiesResults"]]]


class QueryMedicalStudiesMedicalStudiesResults(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    relevance: Optional[float]
    address: Optional["QueryMedicalStudiesMedicalStudiesResultsAddress"]


class QueryMedicalStudiesMedicalStudiesResultsAddress(BaseModel):
    street_address: Optional[str] = Field(alias="streetAddress")
    city: Optional[str]
    region: Optional[str]
    country: Optional[str]
    postal_code: Optional[str] = Field(alias="postalCode")


QueryMedicalStudies.model_rebuild()
QueryMedicalStudiesMedicalStudies.model_rebuild()
QueryMedicalStudiesMedicalStudiesResults.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalDrugClasses(BaseModel):
    delete_medical_drug_classes: Optional[
        List[Optional["DeleteMedicalDrugClassesDeleteMedicalDrugClasses"]]
    ] = Field(alias="deleteMedicalDrugClasses")


class DeleteMedicalDrugClassesDeleteMedicalDrugClasses(BaseModel):
    id: str
    state: EntityState


DeleteMedicalDrugClasses.model_rebuild()
